==> rflutterplugin-0.0.5.tar.gz: ios/Classes/RflutterpluginPlugin.m <==
#import "RflutterpluginPlugin.h"
#import <Appier/Appier.h>

@implementation RflutterpluginPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"rflutterplugin"
            binaryMessenger:[registrar messenger]];
  RflutterpluginPlugin* instance = [[RflutterpluginPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {

    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"QGOnStart" isEqualToString:call.method]) {

    if (call.arguments && [call.arguments isKindOfClass:[NSDictionary class]]) {
       if ([call.arguments objectForKey:@"appId"] && [call.arguments objectForKey:@"isDev"]) {
         NSString *appId = [call.arguments objectForKey:@"appId"];
         bool isDev = [[call.arguments objectForKey:@"isDev"] boolValue];
         NSLog(@"appid:%@", appId);
         NSLog(@"isDev:%d", isDev);
         [[QGSdk getSharedInstance] onStart:appId setDevProfile:isDev];
         result(nil);
         return;
       }
    }
    result(FlutterMethodNotImplemented);
  } else if ([@"QGLogEvent" isEqualToString:call.method]) {
       NSDictionary *parameters = nil;
       if ([call.arguments objectForKey:@"parameters"]) {
         NSLog(@"parameters: %@", [call.arguments objectForKey:@"parameters"]);
         parameters = [call.arguments objectForKey:@"parameters"];
       }
       if ([call.arguments objectForKey:@"eventName"]) {
         [[QGSdk getSharedInstance] logEvent:[call.arguments objectForKey:@"eventName"] withParameters:parameters];
       }
       result(nil);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end

==> rflutterplugin-0.0.6.tar.gz: ios/Classes/RflutterpluginPlugin.m <==
#import "RflutterpluginPlugin.h"
#import <Appier/Appier.h>

@implementation RflutterpluginPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"rflutterplugin"
            binaryMessenger:[registrar messenger]];
  RflutterpluginPlugin* instance = [[RflutterpluginPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {

    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"QGOnStart" isEqualToString:call.method]) {

    if (call.arguments && [call.arguments isKindOfClass:[NSDictionary class]]) {
       if ([call.arguments objectForKey:@"appId"] &&
           [call.arguments objectForKey:@"isDev"] &&
           [call.arguments objectForKey:@"appGroup"]) {
         NSString *appId = [call.arguments objectForKey:@"appId"];
         NSString *appGroup = [call.arguments objectForKey:@"appGroup"];
         bool isDev = [[call.arguments objectForKey:@"isDev"] boolValue];
         NSLog(@"appid:%@", appId);
         NSLog(@"isDev:%d", isDev);
         [[QGSdk getSharedInstance] onStart:appId withAppGroup:appGroup setDevProfile:isDev];
         result(nil);
         return;
       }
    }
    result(FlutterMethodNotImplemented);
  } else if ([@"QGLogEvent" isEqualToString:call.method]) {
       NSDictionary *parameters = nil;
       if ([call.arguments objectForKey:@"parameters"]) {
         NSLog(@"parameters: %@", [call.arguments objectForKey:@"parameters"]);
         parameters = [call.arguments objectForKey:@"parameters"];
       }
       if ([call.arguments objectForKey:@"eventName"]) {
         [[QGSdk getSharedInstance] logEvent:[call.arguments objectForKey:@"eventName"] withParameters:parameters];
       }
       result(nil);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end
